# i3a

Automatic tiling for sway/i3wm manager. The following layouts are possible:

- master-stack area with DWM-like stack (stack windows are split)
- master-stack area with i3-like stack (stack windows are actual stack)
